@@ -67,7 +67,10 @@ class Estimator(AbstractEstimator):
     def estimate(self, design_point: Tuple[int, ...], metric: Metric) -> float:
         if self.__regression_model is RegressionModel.KERNEL_RIDGE:
             estimate = self.__kernel_ridge(list(design_point), metric)
-        elif self.__regression_model is RegressionModel.STREAM_LEARNING:
+        elif self.__regression_model in {
+            RegressionModel.STREAM_LEARNING_ISOUP,
+            RegressionModel.STREAM_LEARNING_STACKED,
+        }:
             estimate = self.__stream_learner(list(design_point), metric)
         else:
             raise Exception(
@@ -125,9 +128,20 @@ class Estimator(AbstractEstimator):
         if self.__last_design_point != design_point:
             X, y = self.__prepare_data(design_point)
         if not self.__last_design_point:
-            self.__reg = skm.trees.iSOUPTreeRegressor(
-                leaf_prediction="adaptive", learning_ratio_const=False,
-            )
+            if (
+                self.__regression_model
+                is RegressionModel.STREAM_LEARNING_ISOUP
+            ):
+                self.__reg = skm.trees.iSOUPTreeRegressor()
+            elif (
+                self.__regression_model
+                is RegressionModel.STREAM_LEARNING_STACKED
+            ):
+                self.__reg = (
+                    skm.trees.StackedSingleTargetHoeffdingTreeRegressor()
+                )
+            else:
+                Exception("Streaming regression model not implemented")
             self.__reg.fit(X, y)
             self.__last_design_point = design_point
             self.__last_len = len(X)
