@@ -50,7 +50,7 @@ class FitnessEvaluator(AbstractFitnessEvaluator):
                 self.__set_threshold(self.estimator.get_examples())
         else:
             print("Fitness estimating")
-            design_value = self.estimator.estimate(list(design_point), metric)
+            design_value = self.estimator.estimate(design_point, metric)
             if design_value is None:
                 if metric.is_frequency:
                     design_value = uniform(
