@@ -1,6 +1,8 @@
 from pathlib import Path
 from typing import Tuple, List, Optional
 from collections import OrderedDict
+
+from numpy.core.defchararray import upper
 from dovado_rtl.config import Configuration
 import dovado_rtl.vivado_interaction as vivado
 from dovado_rtl.frame_handling import (
@@ -220,7 +222,7 @@ def space(
         + " a range and the consecutive closes it (start counting from 1)",
     ),
     fitness_estimator: str = typer.Option(
-        "STREAM_LEARNING",
+        "KERNEL_RIDGE",
         callback=validate_estimator,
         help="estimator to use for fitness function approximation,"
         + "'kernel_ridge' is default. 'stream_learning' selects a Hoeffding Adaptive Tree Regressor trained incrementally",
@@ -246,9 +248,11 @@ def space(
     ranges_dict = OrderedDict(zip(ctx.obj["parameters"], zip(it, it)))
 
     estimator = Estimator(
-        RegressionModel.KERNEL_RIDGE
-        if fitness_estimator.upper() == "KERNEL_RIDGE"
-        else RegressionModel.STREAM_LEARNING,
+        RegressionModel.STREAM_LEARNING_ISOUP
+        if fitness_estimator.upper() == "STREAM_LEARNING_ISOUP"
+        else RegressionModel.STREAM_LEARNING_STACKED
+        if fitness_estimator.upper() == "STREAM_LEARNING_STACKED"
+        else RegressionModel.KERNEL_RIDGE,
         ctx.obj["point_evaluator"],
         ranges_dict,
         int(ctx.obj["config"].get_config("INITIAL_SAMPLES")),
